@@ -8,7 +8,7 @@ from ..config import config
 from ..executor import Executor, render_script_with_tmp_root, run_script
 from ..io import InputArtifact, InputParameter
 from ..op_template import ScriptOPTemplate
-from ..utils import upload_s3
+from ..utils import randstr, upload_s3
 from . import bohrium
 
 try:
@@ -202,6 +202,7 @@ class DispatcherExecutor(Executor):
             return template
 
         new_template = deepcopy(template)
+        new_template.name += "-" + randstr()
         new_template.image = self.image
         new_template.image_pull_policy = self.image_pull_policy
         new_template.command = self.command
@@ -255,7 +256,7 @@ class DispatcherExecutor(Executor):
                     "image_name"] = template.image
 
         self.machine_dict["local_root"] = self.work_root
-        new_template.script += "import json\n"
+        new_template.script += "import json, shlex\n"
         new_template.script += "from dpdispatcher import Machine, Resources,"\
             " Task, Submission\n"
         new_template.script += "machine = Machine.load_from_dict(json.loads("\
@@ -266,6 +267,8 @@ class DispatcherExecutor(Executor):
             for k in new_template.envs.keys():
                 new_template.script += "resources.envs['%s'] = "\
                     "os.environ.get('%s')\n" % (k, k)
+        new_template.script += "resources.envs['ARGO_TEMPLATE'] = "\
+            "shlex.quote(os.environ.get('ARGO_TEMPLATE'))\n"
         new_template.script += "task = Task.load_from_dict(json.loads('%s'))"\
             "\n" % json.dumps(self.task_dict)
         new_template.script += "task.forward_files = list(filter("\
